# Visby

## Project ida
Simple web app to collect and visualization biometric data. To private daily usage and clound deployment try out. Work time challenge: 40h. Check out how much current available LLM really help. 

## Short term goals
1. Simple backeng in python FastApi framework
2. [Swagger](https://github.com/swagger-api/swagger-ui) api documentation
3. Docker containerization
4. [Superset](https://github.com/apache/superset) data visualization
5. CI, CD flow
6. GCP deployment
7. Tests: unit, integration, e2e
## Long term goals
1. Web UI using Node.js
2. Android app in flutter
